@@ -12,24 +12,26 @@ from rra_tools.cli_tools.options import (
     with_input_directory,
     with_num_cores,
     with_output_directory,
+    with_overwrite,
     with_progress_bar,
     with_queue,
     with_verbose,
 )
 
 __all__ = [
+    "RUN_ALL",
+    "ClickOption",
     "handle_exceptions",
     "import_module_from_info",
+    "process_choices",
+    "with_choice",
     "with_debugger",
     "with_dry_run",
     "with_input_directory",
     "with_num_cores",
     "with_output_directory",
+    "with_overwrite",
     "with_progress_bar",
     "with_queue",
     "with_verbose",
-    "process_choices",
-    "with_choice",
-    "RUN_ALL",
-    "ClickOption",
 ]
